using System.Text.Json;
using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service;

public class UserServiceStub : IUserService
{
    private readonly string _jsonFilePath = Path.Combine(Environment.CurrentDirectory, "wwwroot", "fake_data_users.json");


    public async Task saveUsersJson(List<User> users)
    {
        var json = JsonSerializer.Serialize(users, new JsonSerializerOptions { WriteIndented = true });
        await File.WriteAllTextAsync(_jsonFilePath, json);
    }

    public async Task removeUser(User user)
    {
        var data = await getAllUser();
        var u = data.FirstOrDefault(p => p.Id == user.Id);
        if (u != null)
        {
            data.Remove(u);
            await saveUsersJson(data);
        }
    }

    public Task updateRole(User user)
    {
        user.IsAdmin = true;
        return updateUser(user);
    }

    public Task downgradeRole(User user)
    {
        user.IsAdmin = false;
        return updateUser(user);
    }

    public async Task<List<User>> getAllUser()
    {
        if (!File.Exists(_jsonFilePath))
        {
            Console.Out.WriteLine($"{_jsonFilePath} not found");
            return new List<User>();
        }

        var json = await File.ReadAllTextAsync(_jsonFilePath);
        return JsonSerializer.Deserialize<List<User>>(json) ?? new List<User>();
    }

    public async Task<List<User>> getSomeUser(int nb, int page)
    {
        var users = await getAllUser();
        if ((page - 1) * nb + nb > users.Count())
        {
            return users.GetRange(users.Count() - nb, nb);
        }
        return users.GetRange((page - 1) * nb, nb);
    }

    public async Task<User> getOneUser(int id)
    {
        var data = await getAllUser();
        var u = data.FirstOrDefault(p => p.Id == id);
        if (u != null)
        {
            return u;
        }
        return null;
    }

    public Task<List<User>> reserchUsers(string reserch, List<string> args)
    {
        throw new NotImplementedException();
    }

    public async Task<int> getNbUser()
    {
        var data = await getAllUser();
        return data.Count;
    }

    public async Task updateUser(User user)
    {
         var data = await getAllUser();
         var person = data.FirstOrDefault(p => p.Id == user.Id);
         if (person != null)
         {
             person.Name = user.Name;
             person.Email = user.Email;
             person.Image = user.Image;
             person.IsAdmin = user.IsAdmin;
             await saveUsersJson(data);
         }
    }
}